Bootstrap method for mnTS objects
boot.mnTS.RdProvides bootstrapped confidence intervals for an object of class mnTS.
Usage
# S3 method for class 'mnTS'
boot(mod, reps, dispersion.fixed = 1, maxit.optim = 1e+05, ...)
boot.mnTS.RdProvides bootstrapped confidence intervals for an object of class mnTS.
# S3 method for class 'mnTS'
boot(mod, reps, dispersion.fixed = 1, maxit.optim = 1e+05, ...)