Skip to contents

This is a generic bootstrap function for models.

Usage

bootstrap(object, ...)

Arguments

object

An object for which the bootstrap method is defined.

...

Additional arguments passed to the method.

Value

The value returned by the method dispatched on object; see bootstrap.mnTS().

See also