This is a generic bootstrap function for models.
Value
The value returned by the method dispatched on object;
see bootstrap.mnTS().
This is a generic bootstrap function for models.
The value returned by the method dispatched on object;
see bootstrap.mnTS().