Skip to contents

Generates simulated datasets from a fitted mnTS object.

Usage

# S3 method for class 'mnTS'
simulate(mod, ...)

Arguments

mod

An object of class "mnTS", as returned by the mnTS function.

...

Additional arguments passed to the simulation routine.

Value

A simulated dataset in the same structure as the response variable Y used to fit the model.